@@ -118,6 +118,7 @@ class RequestBase(object):
         # Decode values collected by sub classes
         self.path_info = self.decodePagename(self.path_info)
 
+        self.opened_logs = 0
         self.failed = 0
         self._available_actions = None
         self._known_actions = None
@@ -157,6 +158,8 @@ class RequestBase(object):
                 self.makeForbidden(404, 'No wiki configuration matching the URL found!\r\n')
                 return
 
+            self.open_logs()
+
             self.isSpiderAgent = self.check_spider()
         
             # Set decode charsets.  Input from the user is always in
@@ -209,7 +212,6 @@ class RequestBase(object):
             self.content_lang = self.cfg.language_default
             self.getText = lambda text, i18n=self.i18n, request=self, lang=self.lang, **kv: i18n.getText(text, request, lang, kv.get('formatted', True))
 
-            self.opened_logs = 0
             self.reset()
         
     def surge_protect(self, kick_him=False):
@@ -234,7 +236,7 @@ class RequestBase(object):
         try:
             cache = caching.CacheEntry(self, 'surgeprotect', 'surge-log')
             if cache.exists():
-                data = cache.content()
+                data = cache.content(decode=True)
                 data = data.split("\n")
                 for line in data:
                     try:
@@ -282,9 +284,9 @@ class RequestBase(object):
                     for t, surge_indicator in timestamps:
                         data.append("%s\t%d\t%s\t%s" % (id, t, action, surge_indicator))
             data = "\n".join(data)
-            cache.update(data)
+            cache.update(data, encode=True)
         except StandardError, err:
-            pass
+            self.log('%s: %s' % (err.__class__.__name__, str(err)))
 
         return surge_detected   
         
@@ -775,7 +777,38 @@ class RequestBase(object):
         # Add time stamp
         msg = '[%s] %s\n' % (time.asctime(), msg)
         sys.stderr.write(msg)
-    
+
+    def timing_log(self, start, action):
+        """ Log to timing log (for performance analysis) """
+        indicator = ''
+        if start:
+            total = "vvv"
+        else:
+            self.clock.stop('total') # make sure it is stopped
+            total_secs = self.clock.timings['total']
+            # we add some stuff that is easy to grep when searching for peformance problems:
+            if total_secs > 50:
+                indicator += '!4!'
+            elif total_secs > 20:
+               indicator += '!3!'
+            elif total_secs > 10:
+                indicator += '!2!'
+            elif total_secs > 2:
+                indicator += '!1!'
+            total = self.clock.value('total')
+            # use + for existing pages, - for non-existing pages
+            indicator += self.page.exists() and '+' or '-'
+            if self.isSpiderAgent:
+                indicator += "B"
+
+        # Add time stamp and process ID
+        pid = os.getpid()
+        t = time.time()
+        timestr = time.strftime("%Y%m%d %H%M%S", time.gmtime(t))
+        msg = '%s %5d %-6s %4s %-10s %s\n' % (timestr, pid, total, indicator, action, self.url)
+        self.timing_logfile.write(msg)
+        self.timing_logfile.flush()
+
     def write(self, *data):
         """ Write to output stream.
         """
@@ -1058,7 +1091,6 @@ class RequestBase(object):
             # Don't sleep() here, it binds too much of our resources!
             return self.finish()
 
-        self.open_logs()
         _ = self.getText
         self.clock.start('run')
 
@@ -1080,6 +1112,9 @@ class RequestBase(object):
             
             action = self.form.get('action', [None])[0]
 
+            if self.cfg.log_timing:
+                self.timing_log(True, action)
+
             # The last component in path_info is the page name, if any
             path = self.getPathinfo()
             if path.startswith('/'):
@@ -1192,6 +1227,9 @@ space between words. Group page name is not allowed.""") % self.user.name
         except Exception, err:
             self.fail(err)
 
+        if self.cfg.log_timing:
+            self.timing_log(False, action)
+
         return self.finish()
 
     def http_redirect(self, url):
@@ -2015,6 +2053,12 @@ class RequestFastCGI(RequestBase):
             form = self.fcgform
         return RequestBase._setup_args_from_cgi_form(self, form)
 
+    def open_logs(self):
+        # create log file for catching stderr output
+        if not self.opened_logs:
+            sys.stderr = open(os.path.join(self.cfg.data_dir, 'error.log'), 'at', 0)
+            self.opened_logs = 1
+
     def read(self, n=None):
         """ Read from input stream. """
         if n is None:
@@ -2063,6 +2107,14 @@ class RequestFastCGI(RequestBase):
         #sys.stderr.write(pformat(more_headers))
         #sys.stderr.write(pformat(self.user_headers))
 
+    def open_logs(self):
+        # create log file for catching stderr output
+        if not self.opened_logs:
+            sys.stderr = open(os.path.join(self.cfg.data_dir, 'error.log'), 'at')
+            if self.cfg.log_timing:
+                self.timing_logfile = open(os.path.join(self.cfg.data_dir, 'timing.log'), 'at')
+            self.opened_logs = 1
+
 # WSGI --------------------------------------------------------------
 
 class RequestWSGI(RequestBase):
