@@ -376,7 +376,8 @@ class MoinTranslator(html4css1.HTMLTranslator):
                     node['classes'].append(prefix)
             else:
                 # Default case - make a link to a wiki page.
-                page = MoinMoin.Page.Page(self.request, refuri)
+                page = MoinMoin.Page.Page(self.request,
+                                          wikiutil.AbsPageName(self.request, self.formatter.page.page_name, refuri))
                 node['refuri'] = page.url(self.request)
                 if not page.exists():
                     node['classes'].append('nonexistent')
@@ -559,21 +560,28 @@ class MoinDirectives:
             return
 
         if len(content):
-            page = Page(page_name = content[0], request = self.request)
-            if page.exists():
-                text = page.get_raw_body()
-                lines = text.split('\n')
-                # Remove the "#format rst" line
-                if lines[0].startswith("#format"):
-                    del lines[0]
+            pagename = content[0]
+            page = Page(page_name=pagename, request=self.request)
+            if not self.request.user.may.read(pagename):
+                lines = [_("**You are not allowed to read the page: %s**") % (pagename, )]
             else:
-                lines = [_("**Could not find the referenced page: %s**") % (content[0],)]
+                if page.exists():
+                    text = page.get_raw_body()
+                    lines = text.split('\n')
+                    # Remove the "#format rst" line
+                    if lines[0].startswith("#format"):
+                        del lines[0]
+                else:
+                    lines = [_("**Could not find the referenced page: %s**") % (pagename, )]
             # Insert the text from the included document and then continue
             # parsing
             state_machine.insert_input(lines, 'MoinDirectives')
         return
 
-    include.content = True
+    include.has_content = include.content = True
+    include.option_spec = {}
+    include.required_arguments = 1
+    include.optional_arguments = 0
 
     # Add additional macro directive.
     # This allows MoinMoin macros to be used either by using the directive
@@ -595,7 +603,10 @@ class MoinDirectives:
             return [ref]
         return
 
-    macro.content = True
+    macro.has_content = macro.content = True
+    macro.option_spec = {}
+    macro.required_arguments = 1
+    macro.optional_arguments = 0
 
 if ErrorParser: # fixup in case of missing docutils
     Parser = ErrorParser
