@@ -30,11 +30,9 @@ class Parser:
 
     # some common strings
     PARENT_PREFIX = wikiutil.PARENT_PREFIX
-    attachment_schemas = ["attachment", "inline", "drawing"]
     punct_pattern = re.escape(u'''"\'}]|:,.)?!''')
-    url_pattern = (u'http|https|ftp|nntp|news|mailto|telnet|wiki|file|irc|' +
-            u'|'.join(attachment_schemas) + 
-            (config.url_schemas and u'|' + u'|'.join(config.url_schemas) or ''))
+    attachment_schemas = ["attachment", "inline", "drawing", ]
+    url_pattern = u'|'.join(config.url_schemas + attachment_schemas)
 
     # some common rules
     word_rule = ur'(?:(?<![%(u)s%(l)s])|^)%(parent)s(?:%(subpages)s(?:[%(u)s][%(l)s]+){2,})+(?![%(u)s%(l)s]+)' % {
@@ -85,7 +83,7 @@ class Parser:
 (?P<email>[-\w._+]+\@[\w-]+(\.[\w-]+)+)
 (?P<smiley>(?<=\s)(%(smiley)s)(?=\s))
 (?P<smileyA>^(%(smiley)s)(?=\s))
-(?P<ent_symbolic>&[a-zA-Z]+;)
+(?P<ent_symbolic>&\w+;)
 (?P<ent>[<>&])
 (?P<wikiname_bracket>\[".*?"\])
 (?P<tt_bt>`.*?`)"""  % {
