@@ -215,6 +215,9 @@ class Macro:
         return self.formatter.rawHTML(html)
 
     def _macro_WordIndex(self, args):
+        if self.request.isSpiderAgent: # reduce bot cpu usage
+            return ''
+
         _ = self._
         allpages = int(self.form.get('allpages', [0])[0]) != 0
         # Get page list readable by current user
@@ -349,6 +352,9 @@ class Macro:
         return self.formatter.rawHTML(buf.getvalue())
 
     def _macro_SystemInfo(self, args):
+        if self.request.isSpiderAgent: # reduce bot cpu usage
+            return ''
+
         import operator, sys
         from StringIO import StringIO
         from MoinMoin import parser, processor, version
